@@ -25,10 +25,10 @@ class Encoder(Module):
         self.hard = False
 
     def forward(self, x):
-        noise = torch.randn(x.shape[0], x.shape[1]).to(x.device)
-        noise *= torch.linalg.norm(x) / \
-            torch.linalg.norm(noise)*(torch.tensor(10**(self.snr/20)))
-        x = x  # + noise
+        # noise = torch.randn(x.shape[0], x.shape[1]).to(x.device)
+        # noise *= torch.linalg.norm(x) / \
+        #     torch.linalg.norm(noise)*(torch.tensor(10**(self.snr/20)))
+        # x = x + noise
         A = gumbel_sigmoid(self.A, self.t, self.hard)
         # y = self.enc_net(x)
         # A = self.A
@@ -38,25 +38,6 @@ class Encoder(Module):
         return A_loss, y
 
 
-class Decoder(Module):
-    def __init__(self,
-                 m_dim: int = 100,
-                 hidden_dim: int = 128,
-                 in_dim: int = 1200,
-                 **kwargs):
-        super().__init__()
-        self.dec_net = Sequential(Linear(m_dim, hidden_dim),
-                                  Mish(),
-                                  Linear(hidden_dim, hidden_dim),
-                                  Mish(),
-                                  Linear(hidden_dim, in_dim),
-                                  Mish())
-
-    def forward(self, y):
-        x = self.dec_net(y)
-        return x
-
-
 class CSNet(Module):
     def __init__(self,
                  lambda_sparsity: float = 1,
@@ -97,12 +78,8 @@ class CSNet(Module):
 
     def forward(self, batch):
         x, library = batch
-
-        # x_ = torch.log(1+x)
         A_loss, y = self.encoder(x)
-
         y = torch.log(1+y)
-
         z, mu = self.z_sample(y)
         px_scale, px_r, px_rate, px_dropout = self.decoder(
             "gene",
@@ -115,15 +92,17 @@ class CSNet(Module):
         loss_dict['A_loss'] = A_loss
         xhat, loss_dict['recon_loss'] = self.recon(
             recon_type='ZINB', target=x, px_rate=px_rate, px_r=px_r, px_dropout=px_dropout)
-        loss_dict['cos_loss'] = (1-F.cosine_similarity(x, px_rate, dim=1)).sum()
-        loss_dict['cos_loss2'] = (1-F.cosine_similarity(x, px_rate, dim=0)).sum()
-        
-        loss_dict['loss'] = 0        
+        loss_dict['cos_loss'] = (
+            1-F.cosine_similarity(x, px_rate, dim=1)).sum()
+        loss_dict['cos_loss2'] = (
+            1-F.cosine_similarity(x, px_rate, dim=0)).sum()
+
+        loss_dict['loss'] = 0
         for loss_str, lambda_ in zip(['recon_loss', 'A_loss', 'cos_loss', 'cos_loss2'], [1, self.lambda_sparsity, self.lambda_cos, self.lambda_cos]):
             loss_ = loss_dict[loss_str]
-            loss_ = loss_ * lambda_ #/ (loss_/loss_dict['recon_loss']).detach() 
+            # / (loss_/loss_dict['recon_loss']).detach()
+            loss_ = loss_ * lambda_
             loss_dict['loss'] += loss_
-            
 
         return xhat, px_rate, loss_dict
 
